# spec file for package tinyca
#
# Copyright (c) 2002 Stephan Martin
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Adopted for Sisyphus by Nikolay A. Fetisov

Name: tinyca
Version: 0.6.8
Release: alt1.M24.1

Summary: Graphical tool for managing a Certification Authority
Summary(ru_RU.KOI8-R):     Certification Authority

License: GPL
Group: Security/Networking
URL: http://tinyca.sm-zone.net/

Packager: Nikolay A. Fetisov <naf@altlinux.ru>
BuildArch: noarch

Source0: %name-%version.tar.bz2
Source1: %name.xpm
Patch0:  %name-0.6.8-alt-openssl_crl_fix.patch
Patch1:  %name-0.6.8-alt-gui_fonts.patch

AutoReqProv: perl, yes
BuildPreReq: perl-devel, perl-GTK-Gnome, perl-gettext
Requires: openssl

%description
TinyCA is a graphical tool written in Perl/Gtk to manage a small
Certification Authority (CA) using openssl.

TinyCA supports
- creation and revocation of x509 - S/MIME certificates.
- PKCS#10 requests.
- exporting certificates as PEM, DER, TXT, and PKCS#12.
- server certificates for use in web servers, email servers, IPsec,
  and more.
- client certificates for use in web browsers, email clients, IPsec,
  and more.
- creation and management of SubCAs

Authors:
--------
Stephan Martin <sm@sm-zone.net>

%description -l ru_RU.KOI8-R
TinyCA -  ,   Perl/GTK,  
Certification Authority (CA)    openssl.

TinyCA :
-     x509  S/MIME
-  PKCS#10
-     PEM, DER, TXT  PKCS#12
-        web, email,  IPsec,
   ..
-       , 
  ,  IPsec  .
-    SubCA

:
--------
Stephan Martin <sm@sm-zone.net>

%define bindir		%_bindir
%define libdir		%_datadir/TinyCA/lib
%define templatesdir	%_datadir/TinyCA/templates
%define localedir	%_datadir/TinyCA/locale/

# Defining _perl_lib_path for correct work of AutoReqProv
%define _perl_lib_path %libdir


%prep
%setup
%patch0 -p1
%patch1 -p1

%build
# Configure pristine source
perl -pi -e 's:./lib:%libdir:g' tinyca
perl -pi -e 's:./templates:%templatesdir:g' tinyca
perl -pi -e 's:./locale:%localedir:g' tinyca
make -C po

%install
LANGUAGES="de es cs"

%__mkdir -p $RPM_BUILD_ROOT%bindir
%__mkdir -p $RPM_BUILD_ROOT%libdir
%__mkdir -p $RPM_BUILD_ROOT%libdir/GUI
%__mkdir -p $RPM_BUILD_ROOT%templatesdir

%__install -m644 lib/*.pm $RPM_BUILD_ROOT%libdir/
%__install -m644 lib/GUI/*.pm $RPM_BUILD_ROOT%libdir/GUI/
%__install -m644 templates/openssl.cnf $RPM_BUILD_ROOT%templatesdir/
%__install -m755 tinyca $RPM_BUILD_ROOT%bindir/

for LANG in $LANGUAGES; do
   %__mkdir -p $RPM_BUILD_ROOT%localedir/$LANG/LC_MESSAGES/
   %__install -D -m644 locale/$LANG/LC_MESSAGES/tinyca.mo %buildroot%localedir/$LANG/LC_MESSAGES/tinyca.mo
done

%__mkdir -p $RPM_BUILD_ROOT%_iconsdir/
%__install -m644 %SOURCE1 $RPM_BUILD_ROOT%_iconsdir/

%__mkdir -p $RPM_BUILD_ROOT/%_menudir
%__cat << EOF > $RPM_BUILD_ROOT/%_menudir/%name
?package(%name): \
  command="%_bindir/%name"\
  icon="tinyca.xpm" \
  needs="x11" \
  section="Networking/Other" \
  title="TinyCA" \
  longtitle="У.или.а дл. .п.авлени. Certification Authority"
EOF

%find_lang %name	    

%post
%update_menus

%postun
%clean_menus

%files -f %name.lang
%doc CHANGES INSTALL
%_datadir/TinyCA*
%_menudir/%name
%_iconsdir/%name.xpm
%bindir/tinyca

%changelog
* Sun Jun 05 2005 Nikolay A. Fetisov <naf@altlinux.ru> 0.6.8-alt1.M24.1
- Backport for ALT Linux Master 2.4

* Sun Jun 05 2005 Nikolay A. Fetisov <naf@altlinux.ru> 0.6.8-alt2
- Support for openssl>0.9.7g (#7006)
- Fix font selection for work with russian fonts

* Mon Feb 21 2005 Nikolay A. Fetisov <naf@altlinux.ru> 0.6.8-alt1
- new version 0.6.8
- added detection for openssl 0.9.8
- removed crlDistributionPoint for Root-CA
- added patch for multiple OUs 
- added patch for multiple subjectAltName extensions

* Mon Feb 07 2005 Nikolay A. Fetisov <naf@altlinux.ru> 0.6.7-alt1
- new version 0.6.7
- spec file cleanup
- adding icon to the menu entry
- First build for ALT Linux
* Tue Oct 5 2004 - Nikolay A. Fetisov <naf@naf.net.ru>
- First build for Sisyphus
* Fri Aug 13 2004 - sm@sm-zone.net
- czech translation
* Sun Jun 13 2004 - sm@sm-zone.net
- gui polishing
- code cleanup
- some usability improvements
* Wed Jun  2 2004 - sm@sm-zone.net
- gui polishing
- GUI module splitted to several files
* Fri Oct  3 2003 - sm@sm-zone.net
- added a lot of configuration options
- correctly import/show details of requests without extensions
  (thanks to James.Leavitt@anywaregroup.com)
* Mon Sep  1 2003 - sm@sm-zone.net
- added renewal of certificates
* Wed Aug 13 2003 - sm@sm-zone.net
- rewite, now using perl-Gtk
* Sat Jul  5 2003 - sm@sm-zone.net
- added german translation
* Tue Jul  1 2003 - sm@sm-zone.net
- convert index.txt if openssl changed from 0.9.6x to 0.9.7x
* Fri Jun 27 2003 - sm@sm-zone.net
- added export into zip-file
  thanks to ludwig.nussel@suse.de
* Mon Jun 23 2003 - sm@sm-zone.net
- some tiny usability improvements
  thanks to ludwig.nussel@suse.de again
* Thu Jun 19 2003 - sm@sm-zone.net
- some usability improvements
  thanks to ludwig.nussel@suse.de
- some more configuration options
* Fri Oct  4 2002 - sm@sm-zone.net
- Fixed bug exporting keys in PEM format
- Fixed possible empty lines in cert/key/reqlist
  thanks to waldemar.mertke@gmx.de
* Fri Sep 27 2002 - sm@sm-zone.net
- fixed some minor bugs and typos (e.g. concerning openssl 0.9.7)
  thanks to iebgener@yahoo.com and waldemar.mertke@gmx.de
* Wed Aug 21 2002 - sm@sm-zone.net
- fixed revocation
- added some colors
- thanks to curly@e-card.bg
* Sun Aug 18 2002 - sm@sm-zone.net
- new version 0.4.0
- works independent of OpenCA modules now
- some enhancements to functionality (e.g. export of key without
  passwd)
- some smaller bugfixes in usability
- new specfile (thanks to oron@actcom.co.il)
* Thu Jun  6 2002 - Oron Peled <oron@actcom.co.il>
- Cleaned .spec file
* Mon Jun  3 2002 - sm@sm-zone.net
- fixed wrong templatedir when creating new CA
* Sun Jun  2 2002 - sm@sm-zone.net
- fixed some minor bugs and typos
* Sat May 11 2002 - sm@sm-zone.net
- Added parser for x509 extensions
* Fri May 03 2002 - sm@sm-zone.net
- added possibility to view requests/certificates
* Thu Apr 18 2002 - sm@sm-zone.net
- added configuration
* Sun Apr  7 2002 - sm@sm-zone.net
- improved usability
* Sun Mar 31 2002 - sm@sm-zone.net
- added function to delete ca
* Sat Mar 30 2002 - sm@sm-zone.net
- allow import of pkcs#10 requests
* Thu Mar 21 2002 - sm@sm-zone.et
- use different listboxes
* Mon Mar 18 2002 - sm@sm-zone.net
- initial package

